@@ -68,6 +68,20 @@ class Request:
             extra_headers=extra_headers
         )
 
+
+    # ------------------------------------------------------ Public properties ------------------------------------------------------- #
+
+    @property
+    def debug(self):
+        return self._request.debug
+
+    @debug.setter
+    def debug(self, val):
+        self._request.debug = val
+
+
+    # -------------------------------------------------------- Public methods -------------------------------------------------------- #
+
     def get(
         self,
         url: str,
@@ -238,7 +252,12 @@ class Request:
 
     def _set_cookies_for_url(self, url: str, cookies: Dict[str, str], save: bool = False):
         self.cookies = self.cookies or {}
-        self.cookies.update({self._clean_url(url):cookies})
+        url = self._clean_url(url)
+
+        if url not in self.cookies:
+            self.cookies[url] = cookies
+        else:
+            self.cookies[url].update(cookies)
 
         if save:
             self.__save_cookies()
